diff --git a/test/src/main/java/org/springframework/ws/mock/client/AbstractResponseCreator.java b/test/src/main/java/org/springframework/ws/test/client/AbstractResponseCreator.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/AbstractResponseCreator.java
rename to test/src/main/java/org/springframework/ws/test/client/AbstractResponseCreator.java
index a23dc99a..d867cf37 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/AbstractResponseCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/client/AbstractResponseCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/DefaultXPathExpectations.java b/test/src/main/java/org/springframework/ws/test/client/DefaultXPathExpectations.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/client/DefaultXPathExpectations.java
rename to test/src/main/java/org/springframework/ws/test/client/DefaultXPathExpectations.java
index 97340462..488fa114 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/DefaultXPathExpectations.java
+++ b/test/src/main/java/org/springframework/ws/test/client/DefaultXPathExpectations.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
@@ -30,8 +30,8 @@ import org.springframework.xml.xpath.XPathExpressionFactory;
import org.w3c.dom.Node;
-import static org.springframework.ws.mock.support.Assert.assertEquals;
-import static org.springframework.ws.mock.support.Assert.fail;
+import static org.springframework.ws.test.support.Assert.assertEquals;
+import static org.springframework.ws.test.support.Assert.fail;
/**
* Default implementation of {@link XPathExpectations}.
diff --git a/test/src/main/java/org/springframework/ws/mock/client/ErrorResponseCreator.java b/test/src/main/java/org/springframework/ws/test/client/ErrorResponseCreator.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/ErrorResponseCreator.java
rename to test/src/main/java/org/springframework/ws/test/client/ErrorResponseCreator.java
index dba1d79e..f69ba4ee 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/ErrorResponseCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/client/ErrorResponseCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/ExceptionResponseCreator.java b/test/src/main/java/org/springframework/ws/test/client/ExceptionResponseCreator.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/ExceptionResponseCreator.java
rename to test/src/main/java/org/springframework/ws/test/client/ExceptionResponseCreator.java
index 91776f79..2925b00b 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/ExceptionResponseCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/client/ExceptionResponseCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/MockSenderConnection.java b/test/src/main/java/org/springframework/ws/test/client/MockSenderConnection.java
similarity index 98%
rename from test/src/main/java/org/springframework/ws/mock/client/MockSenderConnection.java
rename to test/src/main/java/org/springframework/ws/test/client/MockSenderConnection.java
index 8a05a6a1..eee627a8 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/MockSenderConnection.java
+++ b/test/src/main/java/org/springframework/ws/test/client/MockSenderConnection.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/MockWebServiceMessageSender.java b/test/src/main/java/org/springframework/ws/test/client/MockWebServiceMessageSender.java
similarity index 98%
rename from test/src/main/java/org/springframework/ws/mock/client/MockWebServiceMessageSender.java
rename to test/src/main/java/org/springframework/ws/test/client/MockWebServiceMessageSender.java
index f2e99a38..433379a3 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/MockWebServiceMessageSender.java
+++ b/test/src/main/java/org/springframework/ws/test/client/MockWebServiceMessageSender.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/MockWebServiceMessageSenderHolder.java b/test/src/main/java/org/springframework/ws/test/client/MockWebServiceMessageSenderHolder.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/MockWebServiceMessageSenderHolder.java
rename to test/src/main/java/org/springframework/ws/test/client/MockWebServiceMessageSenderHolder.java
index 898d80e8..140b80d5 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/MockWebServiceMessageSenderHolder.java
+++ b/test/src/main/java/org/springframework/ws/test/client/MockWebServiceMessageSenderHolder.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import org.springframework.core.NamedThreadLocal;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/PayloadResponseCreator.java b/test/src/main/java/org/springframework/ws/test/client/PayloadResponseCreator.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/PayloadResponseCreator.java
rename to test/src/main/java/org/springframework/ws/test/client/PayloadResponseCreator.java
index 4b93da9b..32edaeb2 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/PayloadResponseCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/client/PayloadResponseCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/RequestMatcher.java b/test/src/main/java/org/springframework/ws/test/client/RequestMatcher.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/client/RequestMatcher.java
rename to test/src/main/java/org/springframework/ws/test/client/RequestMatcher.java
index 9f779278..6ad40ca5 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/RequestMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/client/RequestMatcher.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/ResponseActions.java b/test/src/main/java/org/springframework/ws/test/client/ResponseActions.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/client/ResponseActions.java
rename to test/src/main/java/org/springframework/ws/test/client/ResponseActions.java
index cf75f9ae..737912a7 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/ResponseActions.java
+++ b/test/src/main/java/org/springframework/ws/test/client/ResponseActions.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
/**
* Allows for setting up responses. Implementations of this interface are returned by {@link WebServiceMock}.
diff --git a/test/src/main/java/org/springframework/ws/mock/client/ResponseCreator.java b/test/src/main/java/org/springframework/ws/test/client/ResponseCreator.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/ResponseCreator.java
rename to test/src/main/java/org/springframework/ws/test/client/ResponseCreator.java
index d27c31b2..2d061bba 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/ResponseCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/client/ResponseCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/SchemaValidatingRequestMatcher.java b/test/src/main/java/org/springframework/ws/test/client/SchemaValidatingRequestMatcher.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/SchemaValidatingRequestMatcher.java
rename to test/src/main/java/org/springframework/ws/test/client/SchemaValidatingRequestMatcher.java
index 795e6f31..20ad8e8e 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/SchemaValidatingRequestMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/client/SchemaValidatingRequestMatcher.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/SoapFaultResponseCreator.java b/test/src/main/java/org/springframework/ws/test/client/SoapFaultResponseCreator.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/client/SoapFaultResponseCreator.java
rename to test/src/main/java/org/springframework/ws/test/client/SoapFaultResponseCreator.java
index c934ada5..b9080037 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/SoapFaultResponseCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/client/SoapFaultResponseCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
@@ -23,7 +23,7 @@ import java.util.Locale;
import org.springframework.ws.soap.SoapBody;
import org.springframework.ws.soap.SoapMessage;
-import static org.springframework.ws.mock.support.Assert.fail;
+import static org.springframework.ws.test.support.Assert.fail;
/**
* Implementation of {@link ResponseCreator} that responds with a SOAP fault.
diff --git a/test/src/main/java/org/springframework/ws/mock/client/SoapHeaderMatcher.java b/test/src/main/java/org/springframework/ws/test/client/SoapHeaderMatcher.java
similarity index 92%
rename from test/src/main/java/org/springframework/ws/mock/client/SoapHeaderMatcher.java
rename to test/src/main/java/org/springframework/ws/test/client/SoapHeaderMatcher.java
index 361b5df0..9dbb6180 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/SoapHeaderMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/client/SoapHeaderMatcher.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
@@ -26,8 +26,8 @@ import org.springframework.ws.soap.SoapHeader;
import org.springframework.ws.soap.SoapHeaderElement;
import org.springframework.ws.soap.SoapMessage;
-import static org.springframework.ws.mock.support.Assert.assertTrue;
-import static org.springframework.ws.mock.support.Assert.fail;
+import static org.springframework.ws.test.support.Assert.assertTrue;
+import static org.springframework.ws.test.support.Assert.fail;
/**
* Matches SOAP headers.
diff --git a/test/src/main/java/org/springframework/ws/mock/client/ThreadLocalMockWebServiceMessageSender.java b/test/src/main/java/org/springframework/ws/test/client/ThreadLocalMockWebServiceMessageSender.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/client/ThreadLocalMockWebServiceMessageSender.java
rename to test/src/main/java/org/springframework/ws/test/client/ThreadLocalMockWebServiceMessageSender.java
index faa4e0fe..50f8f859 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/ThreadLocalMockWebServiceMessageSender.java
+++ b/test/src/main/java/org/springframework/ws/test/client/ThreadLocalMockWebServiceMessageSender.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/main/java/org/springframework/ws/mock/client/UriMatcher.java b/test/src/main/java/org/springframework/ws/test/client/UriMatcher.java
similarity index 90%
rename from test/src/main/java/org/springframework/ws/mock/client/UriMatcher.java
rename to test/src/main/java/org/springframework/ws/test/client/UriMatcher.java
index 23bf9e75..147f42f5 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/UriMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/client/UriMatcher.java
@@ -14,13 +14,13 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.net.URI;
import org.springframework.ws.WebServiceMessage;
-import static org.springframework.ws.mock.support.Assert.assertEquals;
+import static org.springframework.ws.test.support.Assert.assertEquals;
/**
* Matches {@link URI}s.
diff --git a/test/src/main/java/org/springframework/ws/mock/client/WebServiceMock.java b/test/src/main/java/org/springframework/ws/test/client/WebServiceMock.java
similarity index 98%
rename from test/src/main/java/org/springframework/ws/mock/client/WebServiceMock.java
rename to test/src/main/java/org/springframework/ws/test/client/WebServiceMock.java
index d80becd6..449ca881 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/WebServiceMock.java
+++ b/test/src/main/java/org/springframework/ws/test/client/WebServiceMock.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
@@ -27,7 +27,7 @@ import org.springframework.core.io.Resource;
import org.springframework.util.Assert;
import org.springframework.ws.WebServiceMessage;
import org.springframework.ws.client.core.WebServiceTemplate;
-import org.springframework.ws.mock.support.PayloadDiffMatcher;
+import org.springframework.ws.test.support.PayloadDiffMatcher;
import org.springframework.xml.transform.ResourceSource;
import org.springframework.xml.validation.XmlValidator;
import org.springframework.xml.validation.XmlValidatorFactory;
@@ -37,7 +37,7 @@ import org.springframework.xml.validation.XmlValidatorFactory;
* WebServiceTemplate}, set up expectations on request messages, and create response messages.
*
* The typical usage of this mock is similar to any other mocking library (such as EasyMock), that is:
- * - Statically import {@link org.springframework.ws.mock.client.WebServiceMock org.springframework.ws.mock.client.WebServiceMock.*}.
+ *
- Statically import {@link org.springframework.ws.test.client.WebServiceMock org.springframework.ws.mock.client.WebServiceMock.*}.
*
- Use the {@link #mockWebServiceTemplate(WebServiceTemplate)} method to mock a web service template. Typically,
* this template is configured as a Spring bean, either explicitly or as a property of a class that extends {@link
* org.springframework.ws.client.core.support.WebServiceGatewaySupport WebServiceGatewaySupport}.
- Set up
diff --git a/test/src/main/java/org/springframework/ws/mock/client/XPathExpectations.java b/test/src/main/java/org/springframework/ws/test/client/XPathExpectations.java
similarity index 98%
rename from test/src/main/java/org/springframework/ws/mock/client/XPathExpectations.java
rename to test/src/main/java/org/springframework/ws/test/client/XPathExpectations.java
index ad8cf26d..b6857f5a 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/XPathExpectations.java
+++ b/test/src/main/java/org/springframework/ws/test/client/XPathExpectations.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
/**
* Allows for setting up expectations on XPath expressions.
diff --git a/test/src/main/java/org/springframework/ws/mock/client/package-info.java b/test/src/main/java/org/springframework/ws/test/client/package-info.java
similarity index 87%
rename from test/src/main/java/org/springframework/ws/mock/client/package-info.java
rename to test/src/main/java/org/springframework/ws/test/client/package-info.java
index 80f12ce7..990b41b8 100644
--- a/test/src/main/java/org/springframework/ws/mock/client/package-info.java
+++ b/test/src/main/java/org/springframework/ws/test/client/package-info.java
@@ -16,6 +16,6 @@
/**
* Provides a testing framework for client-side Web service testing. This package contains the
- * {@link org.springframework.ws.mock.client.WebServiceMock}, and various related test interfaces.
+ * {@link org.springframework.ws.test.client.WebServiceMock}, and various related test interfaces.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
diff --git a/test/src/main/java/org/springframework/ws/mock/server/AbstractRequestCreator.java b/test/src/main/java/org/springframework/ws/test/server/AbstractRequestCreator.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/server/AbstractRequestCreator.java
rename to test/src/main/java/org/springframework/ws/test/server/AbstractRequestCreator.java
index 481a7b1a..f9f639a6 100644
--- a/test/src/main/java/org/springframework/ws/mock/server/AbstractRequestCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/server/AbstractRequestCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server;
+package org.springframework.ws.test.server;
import java.io.IOException;
diff --git a/test/src/main/java/org/springframework/ws/mock/server/MockWebServiceClient.java b/test/src/main/java/org/springframework/ws/test/server/MockWebServiceClient.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/server/MockWebServiceClient.java
rename to test/src/main/java/org/springframework/ws/test/server/MockWebServiceClient.java
index 5f31d529..8371c286 100644
--- a/test/src/main/java/org/springframework/ws/mock/server/MockWebServiceClient.java
+++ b/test/src/main/java/org/springframework/ws/test/server/MockWebServiceClient.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server;
+package org.springframework.ws.test.server;
import java.io.IOException;
import java.util.Map;
@@ -29,16 +29,16 @@ import org.springframework.ws.WebServiceMessage;
import org.springframework.ws.WebServiceMessageFactory;
import org.springframework.ws.context.DefaultMessageContext;
import org.springframework.ws.context.MessageContext;
-import org.springframework.ws.mock.support.PayloadDiffMatcher;
import org.springframework.ws.soap.saaj.SaajSoapMessageFactory;
import org.springframework.ws.soap.server.SoapMessageDispatcher;
+import org.springframework.ws.test.support.PayloadDiffMatcher;
import org.springframework.ws.transport.WebServiceMessageReceiver;
import org.springframework.xml.transform.ResourceSource;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
-import static org.springframework.ws.mock.support.Assert.fail;
+import static org.springframework.ws.test.support.Assert.fail;
/**
* @author Arjen Poutsma
diff --git a/test/src/main/java/org/springframework/ws/mock/server/RequestCreator.java b/test/src/main/java/org/springframework/ws/test/server/RequestCreator.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/server/RequestCreator.java
rename to test/src/main/java/org/springframework/ws/test/server/RequestCreator.java
index 31161e12..622f34fd 100644
--- a/test/src/main/java/org/springframework/ws/mock/server/RequestCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/server/RequestCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server;
+package org.springframework.ws.test.server;
import java.io.IOException;
diff --git a/test/src/main/java/org/springframework/ws/mock/server/ResponseActions.java b/test/src/main/java/org/springframework/ws/test/server/ResponseActions.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/server/ResponseActions.java
rename to test/src/main/java/org/springframework/ws/test/server/ResponseActions.java
index 82569542..850d7b41 100644
--- a/test/src/main/java/org/springframework/ws/mock/server/ResponseActions.java
+++ b/test/src/main/java/org/springframework/ws/test/server/ResponseActions.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server;
+package org.springframework.ws.test.server;
import java.io.IOException;
import javax.xml.transform.Source;
diff --git a/test/src/main/java/org/springframework/ws/mock/server/ResponseMatcher.java b/test/src/main/java/org/springframework/ws/test/server/ResponseMatcher.java
similarity index 96%
rename from test/src/main/java/org/springframework/ws/mock/server/ResponseMatcher.java
rename to test/src/main/java/org/springframework/ws/test/server/ResponseMatcher.java
index 122d61d1..6272f8aa 100644
--- a/test/src/main/java/org/springframework/ws/mock/server/ResponseMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/server/ResponseMatcher.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server;
+package org.springframework.ws.test.server;
import java.io.IOException;
diff --git a/test/src/main/java/org/springframework/ws/mock/support/Assert.java b/test/src/main/java/org/springframework/ws/test/support/Assert.java
similarity index 97%
rename from test/src/main/java/org/springframework/ws/mock/support/Assert.java
rename to test/src/main/java/org/springframework/ws/test/support/Assert.java
index 9c9c29fd..9e6f7985 100644
--- a/test/src/main/java/org/springframework/ws/mock/support/Assert.java
+++ b/test/src/main/java/org/springframework/ws/test/support/Assert.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.support;
+package org.springframework.ws.test.support;
/**
* JUnit independent assertion class.
diff --git a/test/src/main/java/org/springframework/ws/mock/support/PayloadDiffMatcher.java b/test/src/main/java/org/springframework/ws/test/support/PayloadDiffMatcher.java
similarity index 95%
rename from test/src/main/java/org/springframework/ws/mock/support/PayloadDiffMatcher.java
rename to test/src/main/java/org/springframework/ws/test/support/PayloadDiffMatcher.java
index cf50bc4e..d2f73f7b 100644
--- a/test/src/main/java/org/springframework/ws/mock/support/PayloadDiffMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/support/PayloadDiffMatcher.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.support;
+package org.springframework.ws.test.support;
import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;
@@ -27,7 +27,7 @@ import org.springframework.xml.transform.TransformerHelper;
import org.custommonkey.xmlunit.Diff;
import org.w3c.dom.Document;
-import static org.springframework.ws.mock.support.Assert.fail;
+import static org.springframework.ws.test.support.Assert.fail;
/**
* Matches {@link Source} payloads.
diff --git a/test/src/test/java/org/springframework/ws/mock/client/DefaultXPathExpectationsTest.java b/test/src/test/java/org/springframework/ws/test/client/DefaultXPathExpectationsTest.java
similarity index 99%
rename from test/src/test/java/org/springframework/ws/mock/client/DefaultXPathExpectationsTest.java
rename to test/src/test/java/org/springframework/ws/test/client/DefaultXPathExpectationsTest.java
index bdbeaeb1..5d1df900 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/DefaultXPathExpectationsTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/DefaultXPathExpectationsTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.util.Collections;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/ErrorResponseCallbackTest.java b/test/src/test/java/org/springframework/ws/test/client/ErrorResponseCallbackTest.java
similarity index 96%
rename from test/src/test/java/org/springframework/ws/mock/client/ErrorResponseCallbackTest.java
rename to test/src/test/java/org/springframework/ws/test/client/ErrorResponseCallbackTest.java
index e349e90a..9be779a4 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/ErrorResponseCallbackTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/ErrorResponseCallbackTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/ExceptionResponseCallbackTest.java b/test/src/test/java/org/springframework/ws/test/client/ExceptionResponseCallbackTest.java
similarity index 96%
rename from test/src/test/java/org/springframework/ws/mock/client/ExceptionResponseCallbackTest.java
rename to test/src/test/java/org/springframework/ws/test/client/ExceptionResponseCallbackTest.java
index 20a457b1..78ed3b86 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/ExceptionResponseCallbackTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/ExceptionResponseCallbackTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/MockSenderConnectionTest.java b/test/src/test/java/org/springframework/ws/test/client/MockSenderConnectionTest.java
similarity index 97%
rename from test/src/test/java/org/springframework/ws/mock/client/MockSenderConnectionTest.java
rename to test/src/test/java/org/springframework/ws/test/client/MockSenderConnectionTest.java
index ce447b1d..688c15e6 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/MockSenderConnectionTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/MockSenderConnectionTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/MockWebServiceMessageSenderTest.java b/test/src/test/java/org/springframework/ws/test/client/MockWebServiceMessageSenderTest.java
similarity index 97%
rename from test/src/test/java/org/springframework/ws/mock/client/MockWebServiceMessageSenderTest.java
rename to test/src/test/java/org/springframework/ws/test/client/MockWebServiceMessageSenderTest.java
index d5a49df4..4ce51366 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/MockWebServiceMessageSenderTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/MockWebServiceMessageSenderTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/SchemaValidatingRequestMatcherTest.java b/test/src/test/java/org/springframework/ws/test/client/SchemaValidatingRequestMatcherTest.java
similarity index 99%
rename from test/src/test/java/org/springframework/ws/mock/client/SchemaValidatingRequestMatcherTest.java
rename to test/src/test/java/org/springframework/ws/test/client/SchemaValidatingRequestMatcherTest.java
index 5d9eea33..0babd832 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/SchemaValidatingRequestMatcherTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/SchemaValidatingRequestMatcherTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/SoapFaultResponseCallbackTest.java b/test/src/test/java/org/springframework/ws/test/client/SoapFaultResponseCallbackTest.java
similarity index 99%
rename from test/src/test/java/org/springframework/ws/mock/client/SoapFaultResponseCallbackTest.java
rename to test/src/test/java/org/springframework/ws/test/client/SoapFaultResponseCallbackTest.java
index 21613d96..8fb55da7 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/SoapFaultResponseCallbackTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/SoapFaultResponseCallbackTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.util.Locale;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/SoapHeaderMatcherTest.java b/test/src/test/java/org/springframework/ws/test/client/SoapHeaderMatcherTest.java
similarity index 98%
rename from test/src/test/java/org/springframework/ws/mock/client/SoapHeaderMatcherTest.java
rename to test/src/test/java/org/springframework/ws/test/client/SoapHeaderMatcherTest.java
index e9bfa517..04d7a4ae 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/SoapHeaderMatcherTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/SoapHeaderMatcherTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import javax.xml.namespace.QName;
import javax.xml.soap.MessageFactory;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/UriMatcherTest.java b/test/src/test/java/org/springframework/ws/test/client/UriMatcherTest.java
similarity index 96%
rename from test/src/test/java/org/springframework/ws/mock/client/UriMatcherTest.java
rename to test/src/test/java/org/springframework/ws/test/client/UriMatcherTest.java
index 5e2073f9..9acb0e31 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/UriMatcherTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/UriMatcherTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.net.URI;
diff --git a/test/src/test/java/org/springframework/ws/mock/client/WebServiceMockTest.java b/test/src/test/java/org/springframework/ws/test/client/WebServiceMockTest.java
similarity index 99%
rename from test/src/test/java/org/springframework/ws/mock/client/WebServiceMockTest.java
rename to test/src/test/java/org/springframework/ws/test/client/WebServiceMockTest.java
index f64ef2ef..ae182921 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/WebServiceMockTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/WebServiceMockTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client;
+package org.springframework.ws.test.client;
import java.io.IOException;
import java.net.URI;
@@ -45,7 +45,7 @@ import org.junit.Test;
import static org.custommonkey.xmlunit.XMLAssert.assertXMLEqual;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
-import static org.springframework.ws.mock.client.WebServiceMock.*;
+import static org.springframework.ws.test.client.WebServiceMock.*;
public class WebServiceMockTest {
diff --git a/test/src/test/java/org/springframework/ws/mock/client/integration/ClientIntegrationTest.java b/test/src/test/java/org/springframework/ws/test/client/integration/ClientIntegrationTest.java
similarity index 91%
rename from test/src/test/java/org/springframework/ws/mock/client/integration/ClientIntegrationTest.java
rename to test/src/test/java/org/springframework/ws/test/client/integration/ClientIntegrationTest.java
index 9b76727d..a1e209f4 100644
--- a/test/src/test/java/org/springframework/ws/mock/client/integration/ClientIntegrationTest.java
+++ b/test/src/test/java/org/springframework/ws/test/client/integration/ClientIntegrationTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.client.integration;
+package org.springframework.ws.test.client.integration;
import javax.xml.transform.Source;
@@ -22,8 +22,8 @@ import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.ws.client.core.WebServiceTemplate;
-import org.springframework.ws.mock.integration.CustomerCountRequest;
-import org.springframework.ws.mock.integration.CustomerCountResponse;
+import org.springframework.ws.test.integration.CustomerCountRequest;
+import org.springframework.ws.test.integration.CustomerCountResponse;
import org.springframework.xml.transform.StringSource;
import org.junit.Before;
@@ -31,7 +31,7 @@ import org.junit.Test;
import org.junit.runner.RunWith;
import static org.junit.Assert.assertEquals;
-import static org.springframework.ws.mock.client.WebServiceMock.*;
+import static org.springframework.ws.test.client.WebServiceMock.*;
/**
* Integration test for client-side WebService testing. In different package so we can't use the package-protected
diff --git a/test/src/test/java/org/springframework/ws/mock/integration/CustomerCountRequest.java b/test/src/test/java/org/springframework/ws/test/integration/CustomerCountRequest.java
similarity index 95%
rename from test/src/test/java/org/springframework/ws/mock/integration/CustomerCountRequest.java
rename to test/src/test/java/org/springframework/ws/test/integration/CustomerCountRequest.java
index f748c43f..cb685b13 100644
--- a/test/src/test/java/org/springframework/ws/mock/integration/CustomerCountRequest.java
+++ b/test/src/test/java/org/springframework/ws/test/integration/CustomerCountRequest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.integration;
+package org.springframework.ws.test.integration;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
diff --git a/test/src/test/java/org/springframework/ws/mock/integration/CustomerCountResponse.java b/test/src/test/java/org/springframework/ws/test/integration/CustomerCountResponse.java
similarity index 95%
rename from test/src/test/java/org/springframework/ws/mock/integration/CustomerCountResponse.java
rename to test/src/test/java/org/springframework/ws/test/integration/CustomerCountResponse.java
index 3a30eb70..617591cf 100644
--- a/test/src/test/java/org/springframework/ws/mock/integration/CustomerCountResponse.java
+++ b/test/src/test/java/org/springframework/ws/test/integration/CustomerCountResponse.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.integration;
+package org.springframework.ws.test.integration;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
diff --git a/test/src/test/java/org/springframework/ws/mock/server/integration/CustomerEndpoint.java b/test/src/test/java/org/springframework/ws/test/server/integration/CustomerEndpoint.java
similarity index 86%
rename from test/src/test/java/org/springframework/ws/mock/server/integration/CustomerEndpoint.java
rename to test/src/test/java/org/springframework/ws/test/server/integration/CustomerEndpoint.java
index db698d57..85f3d2ca 100644
--- a/test/src/test/java/org/springframework/ws/mock/server/integration/CustomerEndpoint.java
+++ b/test/src/test/java/org/springframework/ws/test/server/integration/CustomerEndpoint.java
@@ -14,13 +14,13 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server.integration;
+package org.springframework.ws.test.server.integration;
-import org.springframework.ws.mock.integration.CustomerCountRequest;
-import org.springframework.ws.mock.integration.CustomerCountResponse;
import org.springframework.ws.server.endpoint.annotation.Endpoint;
import org.springframework.ws.server.endpoint.annotation.RequestPayload;
import org.springframework.ws.server.endpoint.annotation.ResponsePayload;
+import org.springframework.ws.test.integration.CustomerCountRequest;
+import org.springframework.ws.test.integration.CustomerCountResponse;
@Endpoint
public class CustomerEndpoint {
diff --git a/test/src/test/java/org/springframework/ws/mock/server/integration/ServerIntegrationTest.java b/test/src/test/java/org/springframework/ws/test/server/integration/ServerIntegrationTest.java
similarity index 94%
rename from test/src/test/java/org/springframework/ws/mock/server/integration/ServerIntegrationTest.java
rename to test/src/test/java/org/springframework/ws/test/server/integration/ServerIntegrationTest.java
index 48bce27c..ba468d18 100644
--- a/test/src/test/java/org/springframework/ws/mock/server/integration/ServerIntegrationTest.java
+++ b/test/src/test/java/org/springframework/ws/test/server/integration/ServerIntegrationTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server.integration;
+package org.springframework.ws.test.server.integration;
import javax.xml.transform.Source;
@@ -22,7 +22,7 @@ import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
-import org.springframework.ws.mock.server.MockWebServiceClient;
+import org.springframework.ws.test.server.MockWebServiceClient;
import org.springframework.xml.transform.StringSource;
import org.junit.Before;
diff --git a/test/src/test/java/org/springframework/ws/mock/support/PayloadDiffMatcherTest.java b/test/src/test/java/org/springframework/ws/test/support/PayloadDiffMatcherTest.java
similarity index 98%
rename from test/src/test/java/org/springframework/ws/mock/support/PayloadDiffMatcherTest.java
rename to test/src/test/java/org/springframework/ws/test/support/PayloadDiffMatcherTest.java
index 1669f399..56ba7278 100644
--- a/test/src/test/java/org/springframework/ws/mock/support/PayloadDiffMatcherTest.java
+++ b/test/src/test/java/org/springframework/ws/test/support/PayloadDiffMatcherTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.support;
+package org.springframework.ws.test.support;
import javax.xml.soap.MessageFactory;
diff --git a/test/src/test/resources/org/springframework/ws/mock/client/integration/integration-test.xml b/test/src/test/resources/org/springframework/ws/test/client/integration/integration-test.xml
similarity index 86%
rename from test/src/test/resources/org/springframework/ws/mock/client/integration/integration-test.xml
rename to test/src/test/resources/org/springframework/ws/test/client/integration/integration-test.xml
index b3fce516..9b5bbe65 100644
--- a/test/src/test/resources/org/springframework/ws/mock/client/integration/integration-test.xml
+++ b/test/src/test/resources/org/springframework/ws/test/client/integration/integration-test.xml
@@ -12,8 +12,8 @@
- org.springframework.ws.mock.integration.CustomerCountRequest
- org.springframework.ws.mock.integration.CustomerCountResponse
+ org.springframework.ws.test.integration.CustomerCountRequest
+ org.springframework.ws.test.integration.CustomerCountResponse
diff --git a/test/src/test/resources/org/springframework/ws/mock/client/schemaValidatingRequestMatcherTest.xsd b/test/src/test/resources/org/springframework/ws/test/client/schemaValidatingRequestMatcherTest.xsd
similarity index 100%
rename from test/src/test/resources/org/springframework/ws/mock/client/schemaValidatingRequestMatcherTest.xsd
rename to test/src/test/resources/org/springframework/ws/test/client/schemaValidatingRequestMatcherTest.xsd
diff --git a/test/src/test/resources/org/springframework/ws/mock/server/integration/integration-test.xml b/test/src/test/resources/org/springframework/ws/test/server/integration/integration-test.xml
similarity index 77%
rename from test/src/test/resources/org/springframework/ws/mock/server/integration/integration-test.xml
rename to test/src/test/resources/org/springframework/ws/test/server/integration/integration-test.xml
index 2b43b7d1..5a29e832 100644
--- a/test/src/test/resources/org/springframework/ws/mock/server/integration/integration-test.xml
+++ b/test/src/test/resources/org/springframework/ws/test/server/integration/integration-test.xml
@@ -5,13 +5,13 @@
-
+
- org.springframework.ws.mock.integration.CustomerCountRequest
- org.springframework.ws.mock.integration.CustomerCountResponse
+ org.springframework.ws.test.integration.CustomerCountRequest
+ org.springframework.ws.test.integration.CustomerCountResponse
diff --git a/test/src/main/java/org/springframework/ws/mock/server/PayloadRequestCreator.java b/test/src/main/java/org/springframework/ws/test/server/PayloadRequestCreator.java
similarity index 93%
rename from test/src/main/java/org/springframework/ws/mock/server/PayloadRequestCreator.java
rename to test/src/main/java/org/springframework/ws/test/server/PayloadRequestCreator.java
index 4e064f10..1b1b5ab5 100644
--- a/test/src/main/java/org/springframework/ws/mock/server/PayloadRequestCreator.java
+++ b/test/src/main/java/org/springframework/ws/test/server/PayloadRequestCreator.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.server;
+package org.springframework.ws.test.server;
import java.io.IOException;
import javax.xml.transform.Source;
@@ -24,7 +24,7 @@ import org.springframework.ws.WebServiceMessage;
import org.springframework.xml.transform.TransformerHelper;
/**
* Implementation of {@link org.springframework.ws.mock.client.ResponseCreator} that writes a {@link
* javax.xml.transform.Source} response.
*
* @author Arjen Poutsma
@@ -24,7 +24,7 @@ import org.springframework.ws.WebServiceMessage;
import org.springframework.xml.transform.TransformerHelper;
/**
- * Implementation of {@link org.springframework.ws.mock.client.ResponseCreator} that writes a {@link
+ * Implementation of {@link org.springframework.ws.test.client.ResponseCreator} that writes a {@link
* javax.xml.transform.Source} response.
*
diff --git a/test/src/main/java/org/springframework/ws/mock/support/DiffMatcher.java b/test/src/main/java/org/springframework/ws/test/support/DiffMatcher.java
similarity index 87%
rename from test/src/main/java/org/springframework/ws/mock/support/DiffMatcher.java
rename to test/src/main/java/org/springframework/ws/test/support/DiffMatcher.java
index b8254b9a..fff9d035 100644
--- a/test/src/main/java/org/springframework/ws/mock/support/DiffMatcher.java
+++ b/test/src/main/java/org/springframework/ws/test/support/DiffMatcher.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.ws.mock.support;
+package org.springframework.ws.test.support;
import java.io.IOException;
@@ -23,11 +23,11 @@ import org.springframework.ws.WebServiceMessage;
import org.custommonkey.xmlunit.Diff;
import org.custommonkey.xmlunit.XMLUnit;
-import static org.springframework.ws.mock.support.Assert.assertTrue;
-import static org.springframework.ws.mock.support.Assert.fail;
+import static org.springframework.ws.test.support.Assert.assertTrue;
+import static org.springframework.ws.test.support.Assert.fail;
/**
* Implementation of {@link org.springframework.ws.mock.client.RequestMatcher} based on XMLUnit's {@link Diff}.
*
* @author Arjen Poutsma
* @since 2.0
@@ -23,11 +23,11 @@ import org.springframework.ws.WebServiceMessage;
/**
- * Implementation of {@link org.springframework.ws.mock.client.RequestMatcher} based on XMLUnit's {@link Diff}.
+ * Implementation of {@link org.springframework.ws.test.client.RequestMatcher} based on XMLUnit's {@link Diff}.
*
* @author Arjen Poutsma